Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetNameOfEachPath ¶
GetNameOfEachPath is used to parse a set of paths to obtain unique and concise names for each path. If the paths are repeated, the returned names may also be repeated. And the order of each name in the array is consistent with the input paths. For example:
["/path1"] >> ["path1"] ["/opt/doris/path1"] >> ["path1"] ["/path1", "/path2"] >> ["path1", "path2"] ["/home/disk1/doris", "/home/disk2/doris"] >> ["doris", "disk2-doris"] ["/home/doris/disk1", "/home/doris/disk2"] >> ["disk1", "disk2"] ["/home/disk1/doris", "/home/disk1/doris", "/home/disk2/doris"] >> ["disk1-doris", "disk1-doris", "disk2-doris"]
func ResolveStorageRootPath ¶
ResolveStorageRootPath transforms a string of storage paths into a slice of StorageRootPathInfo.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.